# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12\x61uth_service.proto"/\n\x0cLoginRequest\x12\r\n\x05login\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t"d\n\rLoginResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\t\x12\x12\n\ntoken_type\x18\x04 \x01(\t",\n\x13RefreshTokenRequest\x12\x15\n\rrefresh_token\x18\x01 \x01(\t"k\n\x14RefreshTokenResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\t\x12\x12\n\ntoken_type\x18\x04 \x01(\t"%\n\rLogoutRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t"\x10\n\x0eLogoutResponse")\n\x11\x43heckTokenRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t"\x14\n\x12\x43heckTokenResponse2\xcd\x01\n\x04\x41uth\x12&\n\x05Login\x12\r.LoginRequest\x1a\x0e.LoginResponse\x12;\n\x0cRefreshToken\x12\x14.RefreshTokenRequest\x1a\x15.RefreshTokenResponse\x12)\n\x06Logout\x12\x0e.LogoutRequest\x1a\x0f.LogoutResponse\x12\x35\n\nCheckToken\x12\x12.CheckTokenRequest\x1a\x13.CheckTokenResponseb\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "auth_service_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS is False:

    DESCRIPTOR._options = None
    _LOGINREQUEST._serialized_start = 22
    _LOGINREQUEST._serialized_end = 69
    _LOGINRESPONSE._serialized_start = 71
    _LOGINRESPONSE._serialized_end = 171
    _REFRESHTOKENREQUEST._serialized_start = 173
    _REFRESHTOKENREQUEST._serialized_end = 217
    _REFRESHTOKENRESPONSE._serialized_start = 219
    _REFRESHTOKENRESPONSE._serialized_end = 326
    _LOGOUTREQUEST._serialized_start = 328
    _LOGOUTREQUEST._serialized_end = 365
    _LOGOUTRESPONSE._serialized_start = 367
    _LOGOUTRESPONSE._serialized_end = 383
    _CHECKTOKENREQUEST._serialized_start = 385
    _CHECKTOKENREQUEST._serialized_end = 426
    _CHECKTOKENRESPONSE._serialized_start = 428
    _CHECKTOKENRESPONSE._serialized_end = 448
    _AUTH._serialized_start = 451
    _AUTH._serialized_end = 656
# @@protoc_insertion_point(module_scope)
