# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12user_service.proto"4\n\x11\x43reateUserRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t"/\n\x12\x43reateUserResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t"C\n\x19UpdateUserPasswordRequest\x12\x10\n\x08password\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\t"\x1c\n\x1aUpdateUserPasswordResponse"=\n\x16UpdateUserEmailRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\t"\x19\n\x17UpdateUserEmailResponse"Q\n\x1aGetUserLoginHistoryRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x05"X\n\x10UserLoginHistory\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\x12\x12\n\nip_address\x18\x02 \x01(\t\x12\x12\n\nuser_agent\x18\x03 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x04 \x01(\t"A\n\x1bGetUserLoginHistoryResponse\x12"\n\x07results\x18\x01 \x03(\x0b\x32\x11.UserLoginHistory2\x94\x02\n\x04User\x12\x31\n\x06\x43reate\x12\x12.CreateUserRequest\x1a\x13.CreateUserResponse\x12I\n\x0eUpdatePassword\x12\x1a.UpdateUserPasswordRequest\x1a\x1b.UpdateUserPasswordResponse\x12@\n\x0bUpdateEmail\x12\x17.UpdateUserEmailRequest\x1a\x18.UpdateUserEmailResponse\x12L\n\x0fGetLoginHistory\x12\x1b.GetUserLoginHistoryRequest\x1a\x1c.GetUserLoginHistoryResponseb\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "user_service_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS is False:

    DESCRIPTOR._options = None
    _CREATEUSERREQUEST._serialized_start = 22
    _CREATEUSERREQUEST._serialized_end = 74
    _CREATEUSERRESPONSE._serialized_start = 76
    _CREATEUSERRESPONSE._serialized_end = 123
    _UPDATEUSERPASSWORDREQUEST._serialized_start = 125
    _UPDATEUSERPASSWORDREQUEST._serialized_end = 192
    _UPDATEUSERPASSWORDRESPONSE._serialized_start = 194
    _UPDATEUSERPASSWORDRESPONSE._serialized_end = 222
    _UPDATEUSEREMAILREQUEST._serialized_start = 224
    _UPDATEUSEREMAILREQUEST._serialized_end = 285
    _UPDATEUSEREMAILRESPONSE._serialized_start = 287
    _UPDATEUSEREMAILRESPONSE._serialized_end = 312
    _GETUSERLOGINHISTORYREQUEST._serialized_start = 314
    _GETUSERLOGINHISTORYREQUEST._serialized_end = 395
    _USERLOGINHISTORY._serialized_start = 397
    _USERLOGINHISTORY._serialized_end = 485
    _GETUSERLOGINHISTORYRESPONSE._serialized_start = 487
    _GETUSERLOGINHISTORYRESPONSE._serialized_end = 552
    _USER._serialized_start = 555
    _USER._serialized_end = 831
# @@protoc_insertion_point(module_scope)
